## ASCIIscape

A simple Python CLI tool for converting images to ASCII strings, using numpy, Pillow and rich.
I hope you can enjoy my first PyPi package project!

### Usage

`python -m asciiscape`<br>
Just type this on your terminal and follow the instructions 😉.